#
# Windows makefile for AFFLIB & libewf
#
# These are things you may need to change:

#
# SDK_DIR is where the Windows Platform SDK is installed on your computer
#
SDK_DIR = "C:\Program Files\Microsoft Platform SDK for Windows Server 2003 R2"

# COMPILER_MODE specifies how you want the libaries compiled:

COMPILE_MODE = /MT

TARGETS = afcat.exe

################################################################

INCS =	/I.\
	/Izlib-1.2.3\ \
	/I..\lib \
	/I..\lzma443\C \
	/I..\lzma443\C\7zip\Compress\LZMA_Alone \
	/I..\libewf\include \
	/I$(SDK_DIR)/Include

DEFS = /DHAVE_CONFIG_WINDOWS_H /DWIN32 /DWIN32_NT /DUSE_LIBEWF /DMSC  \
	/D_CRT_SECURE_NO_DEPRECATE 

CC=cl

OTHER_FLAGS = /c /nologo /EHsc /RTC1 /RTCs /ZI /Gm /W2 $(COMPILER_MODE)

CPPFLAGS=$(INCS) $(DEFS) $(OTHER_FLAGS) /Fp"afflib.pch" /Fo$*.obj
CFLAGS=$(INCS) $(DEFS) $(OTHER_FLAGS) /Fp"afflib.pch" /Fo$*.obj

# Here are some useful flags:
# -CODE GENERATION-
# /W4       - warning level 4
# /Gm       - enable minimal rebuild
# /ZI       - enable full Edit and Continue info
# /RTC1     - Enable fast checks
# /RTCs     - Stack Frame runtime checking
#
#
# -PREPROCESSOR-
# /I        - specifies include directory
# /D        - define a switch
#
# -OUTPUT FILES-
# /Fp       - Precompiled headers
#
# -MISCELLANEOUS-
# /nologo   - Disable logo
# /c        - compile only, don't link
#
# -LINKING-
# /MT       - Multithreaded, static link
# /MD       - Multithreaded, Dynamic Link
# /MTd      - Multithreaded, static w/ debugging
# /MDd      - Multithreaded, Dynamic w/ debugging
# Note: "the single-threaded CRT (formerly /ML or /MLd options)
#        are no longer available. Instead, use the multithreaded CRT."
#        http://msdn2.microsoft.com/en-us/library/abx4dbyh(VS.80).aspx

LZMA_OBJS =  \
	..\lzma443\C\7zip\Compress\LZMA_Alone\LzmaBench.obj \
	..\lzma443\C\7zip\Compress\LZMA_Alone\LzmaRam.obj \
	..\lzma443\C\7zip\Compress\LZMA_Alone\LzmaRamDecode.obj \
	..\lzma443\C\7zip\Compress\LZMA_C\LzmaDecode.obj \
	..\lzma443\C\7zip\Compress\Branch\BranchX86.obj \
	..\lzma443\C\7zip\Compress\LZMA\LZMADecoder.obj \
	..\lzma443\C\7zip\Compress\LZMA\LZMAEncoder.obj \
	..\lzma443\C\7zip\Compress\LZ\LZInWindow.obj \
	..\lzma443\C\7zip\Compress\LZ\LZOutWindow.obj \
	..\lzma443\C\7zip\Compress\RangeCoder\RangeCoderBit.obj \
	..\lzma443\C\7zip\Common\InBuffer.obj \
	..\lzma443\C\7zip\Common\OutBuffer.obj \
	..\lzma443\C\7zip\Common\StreamUtils.obj \
	..\lzma443\C\Common\Alloc.obj \
	..\lzma443\C\Common\CommandLineParser.obj \
	..\lzma443\C\Common\CRC.obj \
	..\lzma443\C\Common\String.obj \
	..\lzma443\C\Common\StringConvert.obj \
	..\lzma443\C\Common\StringToInt.obj \
	..\lzma443\C\Common\Vector.obj 

AFF_OBJS = ..\lib\aff_db.obj \
	..\lib\aff_toc.obj \
	..\lib\afflib.obj \
	..\lib\afflib_os.obj \
	..\lib\afflib_pages.obj \
	..\lib\afflib_stream.obj \
	..\lib\afflib_util.obj \
	..\lib\base64.obj \
	..\lib\lzma_glue.obj \
	..\lib\s3_glue.obj \
	..\lib\vnode_aff.obj \
	..\lib\vnode_afd.obj \
	..\lib\vnode_afm.obj \
	..\lib\vnode_ewf.obj \
	..\lib\vnode_raw.obj \
	..\lib\vnode_s3.obj \
	..\lib\vnode_split_raw.obj 

EWF_OBJS = ..\libewf\libewf\ewf_compress.obj \
	..\libewf\libewf\ewf_crc.obj \
	..\libewf\libewf\ewf_data.obj \
	..\libewf\libewf\ewf_digest_hash.obj \
	..\libewf\libewf\ewf_error2.obj \
	..\libewf\libewf\ewf_file_header.obj \
	..\libewf\libewf\ewf_hash.obj \
	..\libewf\libewf\ewf_ltree.obj \
	..\libewf\libewf\ewf_section.obj \
	..\libewf\libewf\ewf_string.obj \
	..\libewf\libewf\ewf_table.obj \
	..\libewf\libewf\ewf_volume.obj \
	..\libewf\libewf\ewf_volume_smart.obj \
	..\libewf\libewf\libewf.obj \
	..\libewf\libewf\libewf_chunk_cache.obj \
	..\libewf\libewf\libewf_common.obj \
	..\libewf\libewf\libewf_debug.obj \
	..\libewf\libewf\libewf_digest_context.obj \
	..\libewf\libewf\libewf_endian.obj \
	..\libewf\libewf\libewf_error_sector.obj \
	..\libewf\libewf\libewf_file.obj \
	..\libewf\libewf\libewf_handle.obj \
	..\libewf\libewf\libewf_hash_values.obj \
	..\libewf\libewf\libewf_header_values.obj \
	..\libewf\libewf\libewf_notify.obj \
	..\libewf\libewf\libewf_offset_table.obj \
	..\libewf\libewf\libewf_read.obj \
	..\libewf\libewf\libewf_section.obj \
	..\libewf\libewf\libewf_section_list.obj \
	..\libewf\libewf\libewf_segment_table.obj \
	..\libewf\libewf\libewf_string.obj \
	..\libewf\libewf\libewf_write.obj

ZLIB_OBJS = zlib-1.2.3\adler32.obj \
	zlib-1.2.3\compress.obj \
	zlib-1.2.3\crc32.obj \
	zlib-1.2.3\deflate.obj \
	zlib-1.2.3\gzio.obj \
	zlib-1.2.3\infback.obj \
	zlib-1.2.3\inffast.obj \
	zlib-1.2.3\inflate.obj \
	zlib-1.2.3\inftrees.obj \
	zlib-1.2.3\trees.obj \
	zlib-1.2.3\uncompr.obj \
	zlib-1.2.3\zutil.obj

#
# WIN32_OBJS are extra objects we need on windows because
# they aren't present
#
WIN32_OBJS = getopt.obj md5.obj 


# LIB_OBJS are all of the objects that we'll put in the library

LIB_OBJS = $(EWF_OBJS)	$(AFF_OBJS) $(LZMA_OBJS)  $(WIN32_OBJS) $(ZLIB_OBJS)

afflib.lib: $(LIB_OBJS)
	lib -out:afflib.lib $(LIB_OBJS)

# WIN32_LIBS are the libraries that we link with on win32
# ws2_32.lib = Winsock 2
# advapi32.lib = CryptoAPI support DLL (LIBEWF uses crypto api)

WIN32LIBS = ws2_32.lib advapi32.lib 

clean:
	del afflib.lib $(LIB_OBJS) $(TARGETS)

LINK_OPTS = /libpath:$(SDK_DIR)/Lib /nodefaultlib:libc $(WIN32LIBS)

afcat.exe: ..\tools\afcat.obj afflib.lib
	link -out:afcat.exe ..\tools\afcat.obj afflib.lib $(LINK_OPTS)

